@@ -620,6 +620,7 @@ void KArchiveTest::testTarCopyTo()
 void KArchiveTest::testTarReadWrite()
 {
     QFETCH(QString, fileName);
+    QFETCH(QString, mimeType);
 
     // testCreateTar must have been run first.
     {
@@ -632,6 +633,17 @@ void KArchiveTest::testTarReadWrite()
         QVERIFY(tar.close());
     }
 
+    {
+        // Now test with KCompressionDevice
+        KCompressionDevice kd(std::make_unique<QFile>(fileName), KCompressionDevice::compressionTypeForMimeType(mimeType));
+        KTar tar(&kd);
+        QVERIFY(tar.open(QIODevice::ReadOnly));
+
+        testFileData(&tar);
+
+        QVERIFY(tar.close());
+    }
+
     // Reopen it and check it
     {
         KTar tar(fileName);
@@ -907,7 +919,7 @@ void KArchiveTest::testTarGzHugeMemoryUsage()
     QVERIFY(!filePath.isEmpty());
 
     KTar tar(filePath);
-    tar.open(QIODevice::ReadOnly);
+    QVERIFY(!tar.open(QIODevice::ReadOnly));
 }
 
 void KArchiveTest::testTarIgnoreRelativePathOutsideArchive()
@@ -1967,8 +1979,10 @@ void KArchiveTest::test7ZipOssFuzzIssues_data()
     QTest::newRow("testcase_4566647131406336") << "data/ossfuzz_testcase_4566647131406336.7z";
     QTest::newRow("testcase_4784793343819776") << "data/ossfuzz_testcase_4784793343819776.7z";
     QTest::newRow("testcase_5082404562993152") << "data/ossfuzz_testcase_5082404562993152.7z";
+    QTest::newRow("testcase_5125023070486528") << "data/ossfuzz_testcase_5125023070486528.7z";
     QTest::newRow("testcase_5132547098214400") << "data/ossfuzz_testcase_5132547098214400.7z";
     QTest::newRow("testcase_5141245598171136") << "data/ossfuzz_testcase_5141245598171136.7z";
+    QTest::newRow("testcase_5497856632094720") << "data/ossfuzz_testcase_5497856632094720.7z";
     QTest::newRow("testcase_5560695602348032") << "data/ossfuzz_testcase_5560695602348032.7z";
     QTest::newRow("testcase_5581009572921344") << "data/ossfuzz_testcase_5581009572921344.7z";
     QTest::newRow("testcase_5821682553257984") << "data/ossfuzz_testcase_5821682553257984.7z";
@@ -1980,7 +1994,9 @@ void KArchiveTest::test7ZipOssFuzzIssues_data()
     QTest::newRow("testcase_6366650283917312") << "data/ossfuzz_testcase_6366650283917312.7z";
     QTest::newRow("testcase_6532014901886976") << "data/ossfuzz_testcase_6532014901886976.7z";
     QTest::newRow("testcase_6593198198947840") << "data/ossfuzz_testcase_6593198198947840.7z";
+    QTest::newRow("testcase_6597581431177216") << "data/ossfuzz_testcase_6597581431177216.7z";
     QTest::newRow("testcase_6653406484955136") << "data/ossfuzz_testcase_6653406484955136.7z";
+    QTest::newRow("testcase_6740459604213760") << "data/ossfuzz_testcase_6740459604213760.7z";
 }
 
 void KArchiveTest::test7ZipOssFuzzIssues()
